==> TenfourbirdG3-31.1.2.zip: TenfourbirdG3/Tenfourbird.app/Contents/MacOS/defaults/pref/thunderbird-branding.js <==
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

//@line 6 "/Users/t_mrc-ct/Projects/Tenfourbird/repos/comm-esr31/mail/branding/aurora/thunderbird-branding.js"
// Default start page
pref("mailnews.start_page.url","https://live.mozillamessaging.com/%APP%/start?locale=%LOCALE%&version=%VERSION%&os=%OS%&buildid=%APPBUILDID%");

// start page override to load after an update
pref("mailnews.start_page.override_url","https://live.mozillamessaging.com/%APP%/whatsnew?locale=%LOCALE%&version=%VERSION%&os=%OS%&buildid=%APPBUILDID%");

// Interval: Time between checks for a new version (in seconds)
// nightly=8 hours, official=24 hours
pref("app.update.interval", 28800);

// The time interval between the downloading of mar file chunks in the
// background (in seconds)
pref("app.update.download.backgroundInterval", 60);

// Give the user x seconds to react before showing the big UI. default=24 hours
pref("app.update.promptWaitTime", 86400);

pref("app.vendorURL", "http://tenfourbird.sourceforge.jp/");

// Tenfourbird specific prefs
pref("distribution.id", "TenfourbirdG3");
pref("distribution.version", "31.1.2");
pref("distribution.about", "for PowerPC G3");

//@line 33 "/Users/t_mrc-ct/Projects/Tenfourbird/repos/comm-esr31/mail/branding/aurora/thunderbird-branding.js"
pref("app.update.url.manual", "http://en.sourceforge.jp/projects/tenfourbird/releases/");
pref("app.update.url.override","http://tenfourbird.sourceforge.jp/update/1/check.php?name=%DISTRIBUTION%&version=%DISTRIBUTION_VERSION%");

//@line 37 "/Users/t_mrc-ct/Projects/Tenfourbird/repos/comm-esr31/mail/branding/aurora/thunderbird-branding.js"

pref("tenfourbird.update.url.download", "http://tenfourbird.sourceforge.jp/update/1/download.php?name=%DISTRIBUTION%&version=%UPDATE_VERSION%");

==> TenfourbirdG3-31.7.0.zip: TenfourbirdG3/Tenfourbird.app/Contents/MacOS/defaults/pref/thunderbird-branding.js <==
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

//@line 6 "/Users/t_mrc-ct/Projects/Tenfourbird/repos/comm-esr31/mail/branding/aurora/thunderbird-branding.js"
// Default start page
pref("mailnews.start_page.url","https://live.mozillamessaging.com/%APP%/start?locale=%LOCALE%&version=%VERSION%&os=%OS%&buildid=%APPBUILDID%");

// start page override to load after an update
pref("mailnews.start_page.override_url","https://live.mozillamessaging.com/%APP%/whatsnew?locale=%LOCALE%&version=%VERSION%&os=%OS%&buildid=%APPBUILDID%");

// Interval: Time between checks for a new version (in seconds)
// nightly=8 hours, official=24 hours
pref("app.update.interval", 28800);

// The time interval between the downloading of mar file chunks in the
// background (in seconds)
pref("app.update.download.backgroundInterval", 60);

// Give the user x seconds to react before showing the big UI. default=24 hours
pref("app.update.promptWaitTime", 86400);

pref("app.vendorURL", "http://tenfourbird.osdn.jp/");

// Tenfourbird specific prefs
pref("distribution.id", "TenfourbirdG3");
pref("distribution.version", "31.7.0");
pref("distribution.about", "for PowerPC G3");

//@line 33 "/Users/t_mrc-ct/Projects/Tenfourbird/repos/comm-esr31/mail/branding/aurora/thunderbird-branding.js"
pref("app.update.url.manual", "http://en.osdn.jp/projects/tenfourbird/releases/");
pref("app.update.url.override","http://tenfourbird.osdn.jp/update/1/check.php?name=%DISTRIBUTION%&version=%DISTRIBUTION_VERSION%");

//@line 37 "/Users/t_mrc-ct/Projects/Tenfourbird/repos/comm-esr31/mail/branding/aurora/thunderbird-branding.js"

pref("tenfourbird.update.url.download", "http://tenfourbird.osdn.jp/update/1/download.php?name=%DISTRIBUTION%&version=%UPDATE_VERSION%");
